aboutsummaryrefslogtreecommitdiff
path: root/drivers/staging/iio/iio.h
diff options
context:
space:
mode:
authorJonathan Cameron <jic23@cam.ac.uk>2011-09-21 11:15:57 +0100
committerGreg Kroah-Hartman <gregkh@suse.de>2011-09-26 17:31:53 -0700
commit14555b14455f9acbdf0e500ae96140828a970796 (patch)
tree544fdc46abf6257a457b816623540e768e0c9bdc /drivers/staging/iio/iio.h
parent3811cd6291bb5a11c8d830831149d6369e7d3b68 (diff)
staging:iio: replacing term ring with buffer in the IIO core.
They aren't always ring buffers, so just use buffer for all naming. Signed-off-by: Jonathan Cameron <jic23@cam.ac.uk> Signed-off-by: Greg Kroah-Hartman <gregkh@suse.de>
Diffstat (limited to 'drivers/staging/iio/iio.h')
-rw-r--r--drivers/staging/iio/iio.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/drivers/staging/iio/iio.h b/drivers/staging/iio/iio.h
index 0f657c773d7..4851d6fb9eb 100644
--- a/drivers/staging/iio/iio.h
+++ b/drivers/staging/iio/iio.h
@@ -276,13 +276,13 @@ struct iio_info {
* @dev: [DRIVER] device structure, should be assigned a parent
* and owner
* @event_interface: [INTERN] event chrdevs associated with interrupt lines
- * @ring: [DRIVER] any ring buffer present
+ * @buffer: [DRIVER] any buffer present
* @mlock: [INTERN] lock used to prevent simultaneous device state
* changes
* @available_scan_masks: [DRIVER] optional array of allowed bitmasks
* @masklength: [INTERN] the length of the mask established from
* channels
- * @trig: [INTERN] current device trigger (ring buffer modes)
+ * @trig: [INTERN] current device trigger (buffer modes)
* @pollfunc: [DRIVER] function run on trigger being received
* @channels: [DRIVER] channel specification structure table
* @num_channels: [DRIVER] number of chanels specified in @channels.
@@ -304,7 +304,7 @@ struct iio_dev {
struct iio_event_interface *event_interface;
- struct iio_ring_buffer *ring;
+ struct iio_buffer *buffer;
struct mutex mlock;
unsigned long *available_scan_masks;
@@ -383,10 +383,10 @@ static inline struct iio_dev *iio_priv_to_dev(void *priv)
void iio_free_device(struct iio_dev *dev);
/**
* iio_ring_enabled() - helper function to test if any form of ring is enabled
* @dev_info: IIO device info structure for device
**/
-static inline bool iio_ring_enabled(struct iio_dev *dev_info)
+static inline bool iio_buffer_enabled(struct iio_dev *dev_info)
{
return dev_info->currentmode
& (INDIO_BUFFER_TRIGGERED | INDIO_BUFFER_HARDWARE);
@@ -383,10 +383,10 @@ static inline struct iio_dev *iio_priv_to_dev(void *priv)
void iio_free_device(struct iio_dev *dev);
/**
- * iio_ring_enabled() - helper function to test if any form of ring is enabled
+ * iio_buffer_enabled() - helper function to test if the buffer is enabled
* @dev_info: IIO device info structure for device
**/